=========
DataFrame
=========

This page gives an overview of all public DataFrame methods.

.. toctree::
   :maxdepth: 2
   :hidden:

   aggregation
   attributes
   computation
   descriptive
   export
   group_by
   modify_select
   miscellaneous

.. currentmodule:: polars

.. autoclass:: DataFrame
    :members:
    :noindex:
    :autosummary:
    :autosummary-nosignatures:
